#include <WiFi.h>
#include <HTTPClient.h>

// Wi-Fi credentials
const char* ssid = "TU_SSID";          // Wi-Fi SSID
const char* password = "TU_PASSWORD";  // Wi-Fi Password

// Buzzer setup
const int Modulo_vibrador = 17;  // GPIO pin for the buzzer
int intensidad = 150;  // PWM intensity for the buzzer (0 to 255)

// Sensor data variables (These will be received from the server instead of from the MPU6050)
float accel_ang_x = 0.0;
float accel_ang_y = 0.0;

void setup() {
  // Initialize serial communication
  Serial.begin(115200);

  // Connect to Wi-Fi
  WiFi.begin(ssid, password);
  while (WiFi.status() != WL_CONNECTED) {
    delay(1000);
    Serial.println("Connecting to Wi-Fi...");
  }
  Serial.println("Connected to Wi-Fi");

  pinMode(Modulo_vibrador, OUTPUT); // Set buzzer pin to output

  // Initialize PWM for ESP32 (LED Control PWM)
  ledcSetup(0, 1000, 8); // PWM channel 0, 1kHz frequency, 8-bit resolution
  ledcAttachPin(Modulo_vibrador, 0); // Attach the pin to PWM channel 0
}

void loop() {
  // Request sensor data from the server via HTTP
  if (WiFi.status() == WL_CONNECTED) {
    HTTPClient http;
    String url = "https://alexservernuevo2.000webhostapp.com/";  // Replace with your server URL
    http.begin(url); // Initiate HTTP connection
    int httpResponseCode = http.GET();  // Send GET request

    if (httpResponseCode > 0) {
      String payload = http.getString();
      Serial.println("Server response: " + payload);

      // Search for the sensor data in the response
      int sensor1Index = payload.indexOf("sensor1=") + 8;  // Find the sensor1 value
      int sensor2Index = payload.indexOf("sensor2=") + 8;  // Find the sensor2 value

      if (sensor1Index > 7 && sensor2Index > 7) {
        // Extract sensor values
        String sensor1Value = payload.substring(sensor1Index, payload.indexOf('&', sensor1Index));
        String sensor2Value = payload.substring(sensor2Index, payload.indexOf('&', sensor2Index));

        // Convert the sensor values to floating point angles
        accel_ang_x = sensor1Value.toFloat();
        accel_ang_y = sensor2Value.toFloat();

        // Print the extracted angles
        Serial.print("Received Angulo en X: ");
        Serial.print(accel_ang_x);
        Serial.print("  Angulo en Y: ");
        Serial.println(accel_ang_y);

        // Use these values to control the buzzer
        vibracion(accel_ang_y, Modulo_vibrador);
      } else {
        Serial.println("Sensor data not found in the server response.");
      }
    } else {
      Serial.println("HTTP request failed with code: " + String(httpResponseCode));
    }
    http.end(); // End the HTTP connection
  }

  delay(500); // Wait before making the next request
}

void vibracion(float angulo, int vibrador) {
  if (angulo > 45) {
    int vibracion = 255; // High intensity to trigger buzzer
    ledcWrite(0, vibracion); // Set PWM signal to buzzer
  } else if (angulo < 45) {
    int vibracion = 150; // Lower intensity for a more subtle vibration
    ledcWrite(0, vibracion); // Set PWM signal to buzzer
    delay(200);
    ledcWrite(0, 0); // Reset PWM to 0 (turn off buzzer)
    delay(200);
  }
}
